@@ -26,8 +26,7 @@ from .tools import __replace_all_envs_in_str
 from .tools import __running_as_root_or_sudo
 from .tools import _makedirs
 from .tools import __try_to_set_owner
-from .tools import __empty_dir
-from .tools import __remove_tree
+from .tools import whoami
 from .tools import abort
 from .tools import _get_version
 from . import cli, pass_config, Commands
@@ -228,16 +227,11 @@ def _do_compose(config, db="", demo=False, **forced_values):
     from .myconfigparser import MyConfigParser
     from .settings import _export_settings
 
-    if os.getenv("SUDO_UID"):
-        whoami = f"{os.environ['SUDO_USER']} {os.environ['SUDO_UID']}"
-    else:
-        whoami = str(pwd.getpwuid(os.getuid())[0])
-
     rows = []
     headers = ["Name", "Value"]
     rows.append(("project-name", config.project_name))
     rows.append(("cwd", os.getcwd()))
-    rows.append(("whoami", whoami))
+    rows.append(("whoami", whoami()))
     rows.append(("run-dir", config.dirs["run"]))
     rows.append(("cmd", " ".join(sys.argv)))
     if config.restrict:
@@ -283,7 +277,7 @@ def _download_images(config, images_url):
         cwd=config.dirs["images"],
     )
     current_branch = subprocess.check_output(
-        ["git", "branch", "--show-current"], encoding="utf8", cwd=config.dirs['images']
+        ["git", "branch", "--show-current"], encoding="utf8", cwd=config.dirs["images"]
     ).strip()
     if config.ODOO_IMAGES_BRANCH and config.ODOO_IMAGES_BRANCH != current_branch:
         subprocess.check_call(["git", "checkout", config.ODOO_IMAGES_BRANCH])
@@ -325,9 +319,7 @@ def _download_images(config, images_url):
         click.secho(f"Clean repository", fg="yellow")
     click.secho("--------------------------------------------------")
     if os.getenv("SUDO_UID"):
-        subprocess.check_call(
-            ["chown", os.environ["SUDO_USER"], "-R", config.dirs["images"]]
-        )
+        subprocess.check_call(["chown", whoami(), "-R", config.dirs["images"]])
     time.sleep(1.0)
 
 
@@ -418,7 +410,7 @@ def _execute_after_compose(config, yml):
 
         duration = (arrow.get() - started).total_seconds()
         if duration > 2:
-            click.secho(f"Processing took {module} seconds", fg='yellow')
+            click.secho(f"Processing took {module} seconds", fg="yellow")
 
     settings.write()
     return yml
